%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?license: %global license %%doc}

%global git_commit 648dbbf

# The only reason we are archful is because dmidecode is ExclusiveArch
# https://bugzilla.redhat.com/show_bug.cgi?id=1067089
%global debug_package %{nil}

Name:           cloud-init
Version:        0.7.7
Release:        10.20160817git%{git_commit}%{?dist}
Summary:        Cloud instance init scripts

Group:          System Environment/Base
License:        GPLv3
URL:            http://launchpad.net/cloud-init
Source0:        %{version}/+download/%{name}-%{version}-%{git_commit}.tar.gz
Source1:        cloud-init-rhel.cfg
Source2:        cloud-init-README.rhel
Source3:        cloud-init-tmpfiles.conf
Source4:	cloudinit.te

Patch0001: 0001-do-not-use-git-for-version-during-package-build.patch
Patch0002: 0002-use-usr-lib-instead-of-lib-for-LIB.patch
Patch0003: 0003-do-not-require-argparse.patch
Patch0004: 0004-use-jinja2-for-console-messages.patch
Patch0005: 0005-rename-dhclient-hook-script.patch

# Deal with noarch -> arch
# https://bugzilla.redhat.com/show_bug.cgi?id=1067089
Obsoletes:      cloud-init < 0.7.5-3

BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  systemd-units
BuildRequires:  git
BuildRequires:  selinux-policy-devel

%ifarch %{?ix86} x86_64 ia64
Requires:       dmidecode
%endif
Requires:       e2fsprogs
Requires:       iproute
Requires:       libselinux-python
Requires:       net-tools
Requires:       policycoreutils-python
Requires:       procps
Requires:       pyserial
Requires:       python-configobj
Requires:	python-jinja2
Requires:       python-jsonpatch
Requires:       python-oauthlib
Requires:       python-prettytable
Requires:       python-requests
Requires:       python-setuptools
Requires:       PyYAML
Requires:       shadow-utils
Requires:       /usr/bin/run-parts

Requires(post):   systemd-units
Requires(post):   policycoreutils-python
Requires(preun):  systemd-units
Requires(postun): systemd-units

%description
Cloud-init is a set of init scripts for cloud instances.  Cloud instances
need special scripts to run during initialization to retrieve and install
ssh keys and to let the user run various scripts.


%prep
# on el7, autosetup -S git was failing with patches that
# create new files.  rpm 4.11.3 and later has -S git_am, but
# el7 only has 4.11.1.
%autosetup -p1 -n %{name}-%{version}-%{git_commit} -S git

cp -p %{SOURCE2} README.rhel


%build
%{__python} setup.py build


%install
rm -rf $RPM_BUILD_ROOT
%{__python} setup.py install -O1 --skip-build --root $RPM_BUILD_ROOT  --init-system=systemd

# Don't ship the tests
rm -r $RPM_BUILD_ROOT%{python_sitelib}/tests

mkdir -p $RPM_BUILD_ROOT/var/lib/cloud

# /run/cloud-init needs a tmpfiles.d entry
mkdir -p $RPM_BUILD_ROOT/run/cloud-init
mkdir -p         $RPM_BUILD_ROOT/%{_tmpfilesdir}
cp -p %{SOURCE3} $RPM_BUILD_ROOT/%{_tmpfilesdir}/%{name}.conf

# We supply our own config file since our software differs from Ubuntu's.
cp -p %{SOURCE1} $RPM_BUILD_ROOT/%{_sysconfdir}/cloud/cloud.cfg

mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/rsyslog.d
cp -p tools/21-cloudinit.conf $RPM_BUILD_ROOT/%{_sysconfdir}/rsyslog.d/21-cloudinit.conf

# Install the systemd bits
mkdir -p         $RPM_BUILD_ROOT/%{_unitdir}
cp -p systemd/*  $RPM_BUILD_ROOT/%{_unitdir}

mkdir -p $RPM_BUILD_ROOT/etc/dhcp/dhclient.d
install -m 755 tools/cloud-init-hook-rhel.sh \
	$RPM_BUILD_ROOT/etc/dhcp/dhclient.d/cloud-init-hook-rhel.sh

# remove unused hooks
rm -f $RPM_BUILD_ROOT/etc/NetworkManager/dispatcher.d/hook-network-manager
rm -f $RPM_BUILD_ROOT/etc/dhcp/dhclient-exit-hooks.d/hook-dhclient

# build selinux policy module
cp %{SOURCE4} .
make -f %{_datadir}/selinux/devel/Makefile cloudinit.pp
install -m 644 -p -D cloudinit.pp \
	$RPM_BUILD_ROOT%{_datadir}/selinux/packages/%{name}/cloudinit.pp

%clean
rm -rf $RPM_BUILD_ROOT


%post
if [ $1 -eq 1 ] ; then
    # Initial installation
    # Enabled by default per "runs once then goes away" exception
    /bin/systemctl enable cloud-config.service     >/dev/null 2>&1 || :
    /bin/systemctl enable cloud-final.service      >/dev/null 2>&1 || :
    /bin/systemctl enable cloud-init.service       >/dev/null 2>&1 || :
    /bin/systemctl enable cloud-init-local.service >/dev/null 2>&1 || :

    semodule -i %{_datadir}/selinux/packages/%{name}/cloudinit.pp 2>/dev/null || :
fi

%preun
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    # One-shot services -> no need to stop
    /bin/systemctl --no-reload disable cloud-config.service >/dev/null 2>&1 || :
    /bin/systemctl --no-reload disable cloud-final.service  >/dev/null 2>&1 || :
    /bin/systemctl --no-reload disable cloud-init.service   >/dev/null 2>&1 || :
    /bin/systemctl --no-reload disable cloud-init-local.service >/dev/null 2>&1 || :

    semodule -r cloudinit 2>/dev/null || :
fi

%postun
# One-shot services -> no need to restart
/bin/systemctl daemon-reload >/dev/null 2>&1 || :

if [ "$1" -ge "1" ] ; then # Upgrade
semodule -i %{_datadir}/selinux/packages/%{name}/cloudinit.pp 2>/dev/null || :
fi


%files
%license LICENSE
%doc ChangeLog README.rhel
%config(noreplace) %{_sysconfdir}/cloud/cloud.cfg
%dir               %{_sysconfdir}/cloud/cloud.cfg.d
%config(noreplace) %{_sysconfdir}/cloud/cloud.cfg.d/*.cfg
%doc               %{_sysconfdir}/cloud/cloud.cfg.d/README
%dir               %{_sysconfdir}/cloud/templates
%config(noreplace) %{_sysconfdir}/cloud/templates/*
%{_unitdir}/cloud-config.service
%{_unitdir}/cloud-config.target
%{_unitdir}/cloud-final.service
%{_unitdir}/cloud-init-local.service
%{_unitdir}/cloud-init.service
%{_tmpfilesdir}/%{name}.conf
%{python_sitelib}/*
%{_libexecdir}/%{name}
%{_bindir}/cloud-init*
%doc %{_datadir}/doc/%{name}
%dir /run/cloud-init
%dir /var/lib/cloud

%dir %{_sysconfdir}/rsyslog.d
%config(noreplace) %{_sysconfdir}/rsyslog.d/21-cloudinit.conf

/etc/dhcp/dhclient.d/cloud-init-hook-rhel.sh
%{_udevrulesdir}/66-azure-ephemeral.rules
%{_unitdir}/cloud-init-generator
%{_unitdir}/cloud-init.target
/usr/lib/systemd/system-generators/cloud-init-generator

%{_datadir}/selinux/packages/%{name}/cloudinit.pp
